## Typing stubs for pyaudio

This is a [PEP 561](https://peps.python.org/pep-0561/) type stub package for
the `pyaudio` package. It can be used by type checkers
to check code that uses `pyaudio`. This version of
`types-pyaudio` aims to provide accurate annotations for
`pyaudio==0.2.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/pyaudio`](https://github.com/python/typeshed/tree/main/stubs/pyaudio)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.16.1
* [pyright](https://github.com/microsoft/pyright) 1.1.403
It was generated from typeshed commit
[`8edafa8029b48c2bb877dde68a572dc4a4349557`](https://github.com/python/typeshed/commit/8edafa8029b48c2bb877dde68a572dc4a4349557).